#
# spec file for package knotifications
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5Notifications5
%define _tar_path 5.76
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           knotifications
Version:        5.76.0
Release:        1.9
Summary:        KDE Desktop notifications
License:        LGPL-2.1-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
Source99:       baselibs.conf
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5Config) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5WindowSystem) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(Qt5DBus) >= 5.12.0
BuildRequires:  cmake(Qt5Test) >= 5.12.0
BuildRequires:  cmake(Qt5TextToSpeech) >= 5.12.0
BuildRequires:  cmake(Qt5Widgets) >= 5.12.0
BuildRequires:  cmake(Qt5X11Extras) >= 5.12.0
BuildRequires:  pkgconfig(dbusmenu-qt5)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(x11)
%if %{with lang}
BuildRequires:  cmake(Qt5LinguistTools) >= 5.12.0
%endif

%description
KNotification is used to notify the user of an event. It covers feedback and
persistent events.

%package -n %{lname}
Summary:        KDE Desktop notifications
Group:          System/GUI/KDE
%if %{with lang}
Recommends:     %{lname}-lang = %{version}
%endif

%description -n %{lname}
KNotification is used to notify the user of an event. It covers feedback and
persistent events.

%package devel
Summary:        KDE Desktop notifications: Build Environment
Group:          Development/Libraries/KDE
Requires:       %{lname} = %{version}
Requires:       extra-cmake-modules
Requires:       cmake(Qt5DBus) >= 5.12.0
Requires:       cmake(Qt5Widgets) >= 5.12.0

%description devel
KNotification is used to notify the user of an event. It covers feedback and
persistent events. Development files.

%lang_package -n %{lname}

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %cmake_build

%install
  %kf5_makeinstall -C build
  %fdupes %{buildroot}

%if %{with lang}
%find_lang %{name}5 --with-qt --without-mo
%endif

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%if %{with lang}
%files -n %{lname}-lang -f %{name}5.lang
%endif

%files -n %{lname}
%license LICENSES/*
%{_kf5_libdir}/libKF5Notifications.so.*
%{_kf5_servicetypesdir}/
%{_kf5_debugdir}/knotifications.categories
%{_kf5_debugdir}/*.renamecategories

%files devel
%{_kf5_libdir}/libKF5Notifications.so
%{_kf5_libdir}/cmake/KF5Notifications/
%{_kf5_includedir}/*.h
%dir %{_kf5_includedir}/*/
%{_kf5_includedir}/*/
%{_kf5_mkspecsdir}/qt_KNotifications.pri
%{_kf5_dbusinterfacesdir}/kf5_org.kde.StatusNotifierItem.xml
%{_kf5_dbusinterfacesdir}/kf5_org.kde.StatusNotifierWatcher.xml

%changelog
* Sat Nov  7 2020 christophe@krop.fr
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * Mark KNotification::activated() as deprecated
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * Apply some sanity checking to action keys (kde#427717)
  * Use FindGradle from ECM
  * Fix condition to use dbus
  * Fix: enable legacy tray on platforms without dbus
  * rewrite notifybysnore to provide more reliable support for
    Windows Stuff not supported in this version of backend
  * Add comments to describe DesktopEntry field in notifyrc file
* Mon Oct  5 2020 christophe@krop.fr
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Changes since 5.74.0:
  * Lower Android plugin until new Gradle is available
  * Use Android SDK versions from ECM
  * const'ify pointer + initialize variable
  * Deprecate KNotification constructor taking widget parameter
* Sun Sep  6 2020 christophe@krop.fr
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Remove obsolete COPYING files
  * refine knotification docs
* Sun Aug  2 2020 christophe@krop.fr
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * KNotifications: Convert license statements to SPDX
  * Use KF-standardized Qt logging categories
  * Use camelcase include. (scripted)
* Sun Jul  5 2020 christophe@krop.fr
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Don't use notifybysnore.h on MSYS2
* Sun Jun  7 2020 christophe@krop.fr
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Implement lock-screen visibility control on Android
  * Generate DBus interface
  * Implement notification grouping on Android
  * Display rich text notification messages on Android
  * Implement urls using hints
  * Use UI marker context in more tr() calls
  * Implement support for notification urgency on Android
  * Remove galago from method/variable naming
  * Remove checks for notification service and fallback to KPassivePopup
* Sun May  3 2020 christophe@krop.fr
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * Implement updating of notifications on Android
  * Handle multi-line and rich-text notifications on Android
  * Add KNotificationJobUiDelegate(KJobUiDelegate::Flags) constructor
  * [KNotificationJobUiDelegate] Append "Failed" for error messages
* Sun Apr  5 2020 christophe@krop.fr
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * Introduce KNotificationJobUiDelegate
  * Use fallback also on Windows not only mac
* Sun Mar  8 2020 christophe@krop.fr
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Fix config include
  * Make kstatusnotifieritem available without dbus
  * Adapt action numbering in Android to work like in KNotifications
  * Fix minor EBN issues and typos
  * Have kai the knotifications maintainer
  * Always strip html if server does not support it
  * Use ecm_qt_install_logging_categories over manual categories file
  * [android] Emit defaultActivated when tapping the notification
* Sun Feb  2 2020 christophe@krop.fr
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 christophe@krop.fr
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * Add new signal for default action activation
  * Drop dependency to KF5Codecs by using the new
    stripRichText function
  * Strip richtext on Windows
  * Reduce dependencies on Windows
  * Adapt to Qt 5.14 Android changes
  * Don't use KWindowSystem on Android
  * Deprecate raiseWidget
  * Port KNotification from KWindowSystem
* Sun Jan  5 2020 christophe@krop.fr
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Port endl to "\n" (QFile flushs data when deleted)
  * Update the obsolete projects.kde.org URL
* Sun Dec  8 2019 christophe@krop.fr
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * Add missing include for Qt 5.14 build
  * Make the docs reflect that setIconName should be preferred
    over setPixmap when possible
  * Document configuration file path on Android
  * Disable knotification_test, which starts D-Bus if it is not
    already running, which on Windows causes the test to hang infinitely
* Sun Nov  3 2019 christophe@krop.fr
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * [KStatusNotifierItem] Allow left click when menu is null
  * Remove Growl support
  * Add and enable Notification Center support in macOS
* Sun Oct  6 2019 christophe@krop.fr
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Port from delta(); to angleDelta().y()
* Sat Sep  7 2019 christophe@krop.fr
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Remove duplicate description and URL from canberra's feature properties
  * Fix build on the CI
  * Resolve whether there's dbus before processing src/
  * avoid duplicate notifications from showing up on Windows and remove whitespaces
  * have 1024x1024 app icon as fallback icon in Snore
  * add `-pid` parameter to Snore backend calls
  * Remove unused DBus XML file
  * Remove double check for DBus
  * add snoretoast backend for KNotifications on Windows
  * Add QVector include
  * Remove unused includes
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 christophe@krop.fr
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * remove dbus for windows build and change audio dep logic
* Fri Jul 19 2019 wbauer@tmo.at
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Don't search for phonon on Android
  * Install in new logging directory when we use kf5 5.59.0
  * add .vscode to .gitignore
* Tue Jul  9 2019 wbauer@tmo.at
- Add missing Qt5DBus requirement to the devel package
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Simpler check for flatpak
  * Handle apps which set the desktopFileName property with filename suffix
  * Fix compilation on MacOS.
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * [Notify by Portal] Support default action and priority hints
  * [KNotification] Add HighUrgency
  * [KNotifications] Update when flags, urls, or urgency change
  * Allow to set urgency for notifications
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * [KStatusNotifierItem] Send desktop-entry hint
  * Allow to set custom hints for notifications
  * [knotifications] compile without foreach
  * [knotifications] compile without deprecated methods
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Port deprecated methods
  * fix some compile error
  * port to findcanberra from ECM
  * List Android as officially supported
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Fix memory leak when passing icon data to Java
  * Remove the AndroidX support library dependency
  * Add Android notification channel support
  * Make notifications work on Android with API level < 23
  * Move the Android API level checks to runtime
  * Remove unused forward declaration
  * Rebuild AAR when Java sources change
  * Build the Java side with Gradle, as AAR instead of JAR
  * Don't rely on the Plasma workspace integration on Android
  * Search for notfication event configuration in qrc resources
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * [Android] Fail more gracefully when building with API < 23
  * Add Android notification backend
  * Initialize pointer
  * Build without D-Bus on Android
  * Clean up tests build system
  * Don't force Phonon on Android
  * Hide API documentation of internal classes
- BuildRequire libcanberra instead of Phonon for notification sounds
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Rename NotifyByFlatpak to NotifyByPortal
  * Notification portal: support pixmaps in notifications
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Revert some port to function-object based connect
  * Use more function-pointer based connect
  * Avoid creation of temporary list
  * Do not include Qt module header
  * Use prefix ++ operator for loop value
  * Do not return void values in void methods
  * Add missing "emit"
  * Move categories file here
  * force-finish canberra notifications on close() (kde#398695)
* Tue Oct 16 2018 lbeltrame@kde.org
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * force-finish canberra notifications on close() (kde#398695)
  * Fix minor EBN issues
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Support libcanberra for audio notification
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * None
- Enable text to speech support in the package
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Fix crashes in NotifyByAudio when closing applications
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Warning-- , use override everywhere
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Add override
  * Make it public
  * Remove not necessary QtCore and co
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Use QWidget to see if the window is visible
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Fix loading NotifyByExecute (kde#389284)
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Port some code to new connect api
  * [KStatusNotifierItem] Don't "restore" widget position on its first show
  * Use positions of legacy systray icons for Minimize/Restore actions
  * Handle positions of LMB clicks on legacy systray icons
  * do not make the context menu a Window
  * Minor optimization
  * Fix comment spelling errors.
  * Add explanatory comment.
  * Lazy-instanciate and lazy-load KNotification plugins.
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Make it compile with QT_NO_CAST_FROM_ASCII
  * Add explicit
  * We already depend against 5.7.0
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Remove check for SNI hosts when chosing whether to use legacy mode (kde#385867)
  * Only check for legacy system tray icons if we're going to make one (kde#385371)
  * Fix cppcheck warning
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * None
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Don't block starting notification service (kde#382444)
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Minor: Fix warning under macOS
  * API dox: use official name "D-Bus" consistently
  * Use more nullptr
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Use explicit flag constructor instead of nullptr/0
  * Fix KSNIs being unable to register service under flatpak
  * API dox: note CamelCase includes by @class tag with more classes
  * Remove unneeded string casts
  * Use application name instead of pid when creating SNI dbus service
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Improve apidox
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Do not remove queued notifications when the fd.o service starts. Also start the service unconditionally when it's not loaded and activatable.
  * Mac platform adaptations
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Removed some dead code.
  * Upgrade KF5 version to 5.32.0.
  * Added missing @since
  * Add support for flatpak portals
  * Only use qApp->desktopFileName() when compiling with Qt >= 5.7.0
  * Send desktopfilename as part of notifyByPopup hints
  * [KStatusNotifierItem] Restore minimized window as normal
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * [KStatusNotifierItem] Save / restore widget position during
    hide / restore it window (kde#356523)
  * [KNotification] Allow annotating notifications with URLs
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Don't deref an object we haven't referenced when notification
    has no action
  * KNotification will no longer crash when using it in a
    QGuiApplication and no notification service is running
    (kde#370667)
  * Fix crashes in NotifyByAudio
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Get StatusNotifierWatcher property ProtocolVersion in async way
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Don't set parent of sublayout manually, silences warning
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Fix notify by taskbar
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Use QUrl::fromUserInput to construct sound url (kde#337276)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Handle left-button clicking on legacy systray icons
    (kde#358589)
  * Only use X11BypassWindowManagerHint flag on platform X11
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * [Notify By Popup] Send along event ID
  * Set default non-empty reason for screen saver inhibition
    (kde#334525)
  * Add a hint to skip notifications grouping (kde#356653)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * Now that kparts no longer needs knotifications, only things that
    really want notifications require on this framework
  * Add description + purpose for speech + phonon
  * Make phonon dependency optional, purely internal change, like
    it is done for speech.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Don't send notification update signal twice
  * Reparse notification config only when it changed
  * Don't try to find X11 on WIN32
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Fix the starting Y position for fallback popups
  * Reduce dependencies and move to Tier 2
  * Catch unknown notification entries (nullptr deref) (kde#348414)
  * Remove pretty much useless warning
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * Fix pixmap types in org.kde.StatusNotifierItem.xml
  * [ksni] Add method to retrieve action by its name (kde#349513)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Fix crash in NotifyByExecute when no widget has been set
    (kde#348510)
  * Improve handling of notifications being closed (kde#342752)
  * Replace QDesktopWidget usage with QScreen
  * Ensure KNotification can be used from a non-GUI thread
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * Fix KNotifications when used with Ubuntu's NotifyOSD
    (kde#345973)
  * Don't trigger notification updates when setting the
    same properties (kde#345973)
  * Introduce LoopSound flag allowing notifications to play sound
    in a loop if they need it (kde#346148)
  * Don't crash if notification doesn't have a widget
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * Added an event() version that takes no icon and will
    use a default one
  * Added an event() version that takes StandardEvent eventId
    and QString iconName
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
- Drop no longer needed kwindowsystem-devel Requires of the
  devel subpackage
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Delay the audio init until actually needed
  * Fix notification config not applying instantly
  * Fix audio notifications stopping after first file played
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Documentation: mentionned the file name requirements of
    .notifyrc files
  * Fixed dangling pointer to KNotification
  * Fixed leak of knotifyconfig
  * Install missing knotifyconfig header
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * Remove NotifyBySound. NotifyByAudio implements the "Sound"
    notification already
  * Fix crash accessing dangling pointer in NotifyByPopup
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Make KNotificationPlugin a public class
  * KPassivePopup - Set default hide delay
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * Add support for custom icons (convenience method
    KNotification::Event with icon name)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * Avoid infinite recursion in KStatusNotifierItem / QSystemTray.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Added libqt5-linguist-devel BuildRequires
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init knotifications package
